==> 0.0.1.tar.gz: example/lib/pages/toastlist.dart <==
import 'package:flutter/material.dart';
import 'package:millui/millui.dart';

class Toastlist extends StatelessWidget {
  _text(context) {
    MillToast.text(context, text: '操作成功');
  }

  _success(context) {
    MillToast.success(context, text: '操作成功');
  }

  _error(context) {
    MillToast.error(context, text: '未知错误');
  }

  _warning(context) {
    MillToast.warning(context, text: '警告');
  }

  _loading(context) {
    MillToast.loading(context, text: '加载中');
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Toast'),
      ),
      body: Container(
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            GestureDetector(
              onTap: () {
                _text(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text('文本'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _success(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text('成功'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _warning(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text('警告'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _error(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text('错误'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _loading(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                child: Text('加载中'),
              ),
            )
          ],
        ),
      ),
    );
  }
}

==> 0.0.4.tar.gz: example/lib/pages/toastlist.dart <==
import 'package:flutter/material.dart';
import 'package:millui/millui.dart';

import '../app_provider.dart';

class Toastlist extends StatelessWidget {
  _text(context) {
    bool isCn = getLanage(context, false);

    MillToast.text(context, text: isCn ? '操作成功' : 'SUCCESS');
  }

  _success(context) {
    bool isCn = getLanage(context, false);

    MillToast.success(context, text: isCn ? '操作成功.' : 'SUCCESS');
  }

  _error(context) {
    bool isCn = getLanage(context, false);

    MillToast.error(context, text: isCn ? '操作成功发生未知错误请联系.' : 'Error');
  }

  _warning(context) {
    bool isCn = getLanage(context, false);

    MillToast.warning(context,
        text: isCn
            ? '操作成功发生未知错误请联系管理员吧，放心吧管理员也不会管用的，哈哈哈哈哈哈哈哈，因为管理员要去约会了，找女盆友呀'
            : 'The information you filled in is incorrect');
  }

  _loading(context) {
    bool isCn = getLanage(context, false);

    MillToast.loading(context, text: isCn ? '操作成功' : 'Loading');
  }

  @override
  Widget build(BuildContext context) {
    bool isCn = getLanage(context);

    return Scaffold(
      appBar: AppBar(
        title: Text('Toast'),
      ),
      body: Container(
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            GestureDetector(
              onTap: () {
                _text(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text(isCn ? '文本' : 'Text'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _success(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text(isCn ? '成功' : 'Success'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _warning(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text(isCn ? '警告' : 'Warning'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _error(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                decoration: BoxDecoration(
                    border: Border(
                        bottom:
                            BorderSide(width: 1.0, color: Color(0xffd9d9d9)))),
                child: Text(isCn ? '错误' : 'Error'),
              ),
            ),
            GestureDetector(
              onTap: () {
                _loading(context);
              },
              child: Container(
                width: 750,
                padding: EdgeInsets.all(20),
                child: Text(isCn ? '加载中' : 'Loading'),
              ),
            )
          ],
        ),
      ),
    );
  }
}
